@@ -7,8 +7,13 @@
 
 =head1 USAGE
 
-    #取出指定帖子，只看楼主，且跟帖内容不能少于100字 
-    tiezi_to_any.pl -b 'http://bbs.jjwxc.net/board.php?board=153&page=1' -o "-p 2" -t "tiezi_to_html.pl -u '{url}' -U 1 -C 100"
+    #取出指定帖子，手动选择，只看楼主，且跟帖内容不能少于100字 
+
+    tiezi_to_any.pl -b "http://bbs.jjwxc.net/board.php?board=153&page=1" -o "-p 2" -t "tiezi_to_html.pl -u \"{url}\" -U 1 -C 100" -m 1
+
+    #取出指定帖子，手动选择，只看楼主，且跟帖内容不能少于100字 
+
+    tiezi_to_any.pl -s HJJ -o "153 贴子主题 迷侠记[初版]" -t "tiezi_to_html.pl -u \"{url}\" -U 1 -C 100" -m 1
 
 =head1 OPTIONS
 
@@ -16,7 +21,7 @@
 
 -s(query) : site
 
--o : option / query keyword
+-o : board option / query keyword
 
 -m : select menu
 
